=====
Usage
=====
Command line interface
----------------------
To use DarkNet OpenSource Neural Networks in Python command line tool:

.. click:: darknet.py.cli:py
  :prog: darknet py
  :show-nested:

Library Usage
-------------
To use DarkNet OpenSource Neural Networks in Python in a project::

    import darknet.py